Rev 5248: Notes about things. in http://bazaar.launchpad.net/~lifeless/bzr/fetch-proposed
Robert Collins
robertc at robertcollins.net
Fri May 21 22:38:56 BST 2010
At http://bazaar.launchpad.net/~lifeless/bzr/fetch-proposed
------------------------------------------------------------
revno: 5248
revision-id: robertc at robertcollins.net-20100521213855-dlwtxc23my3ia30k
parent: pqm at pqm.ubuntu.com-20100521084917-u9sae95g7s0nu2bf
committer: Robert Collins <robertc at robertcollins.net>
branch nick: fetch-proposed
timestamp: Sat 2010-05-22 09:38:55 +1200
message:
Notes about things.
=== modified file 'bzrlib/plugins/launchpad/lp_propose.py'
--- a/bzrlib/plugins/launchpad/lp_propose.py 2010-05-21 07:17:13 +0000
+++ b/bzrlib/plugins/launchpad/lp_propose.py 2010-05-21 21:38:55 +0000
@@ -70,6 +70,7 @@
if staging:
lp_instance = 'staging'
else:
+ # XXX: Should be None, but currently fails due to unknown causes.
lp_instance = 'edge'
service = lp_registration.LaunchpadService(lp_instance=lp_instance)
self.launchpad = lp_api.login(service)
=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- a/bzrlib/plugins/launchpad/lp_registration.py 2010-05-20 18:23:10 +0000
+++ b/bzrlib/plugins/launchpad/lp_registration.py 2010-05-21 21:38:55 +0000
@@ -79,7 +79,10 @@
class LaunchpadService(object):
- """A service to talk to Launchpad via XMLRPC.
+ """A service to talk to Launchpad via XMLRPC (Note: *NOT* 'LP API').
+
+ This is used as a parameter to get an LP API though, see
+ bzrlib.plugins.launchpad.lp_api.
See http://wiki.bazaar.canonical.com/Specs/LaunchpadRpc for the methods we can call.
"""
More information about the bazaar-commits
mailing list